/*
 * ObjectXMLExporter.java 
 *
 * Copyright (c) 2016 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.eteks.sweethome3d.plugin.exporthtml5;

import java.io.IOException;

/**
 * Base class used to export objects to XML.
 * @author Emmanuel Puybaret
 */
public abstract class ObjectXMLExporter<T> {
  public void writeElement(XMLWriter writer, T object) throws IOException {
    writer.writeStartElement(getTag(object));
    writeAttributes(writer, object);
    writeChildren(writer, object);
    writer.writeEndElement();
  }

  /**
   * Returns the element tag matching the object in parameter.
   * @return the simple class name of the exported object with its first letter at lower case,
   *    without <code>Home</code> prefix if it's the case.
   */
  protected String getTag(T object) {
    String className = object.getClass().getSimpleName();
    if (className.startsWith("Home") && !className.equals("Home")) {
      // Remove "Home" prefix
      return Character.toLowerCase(className.charAt(4)) + className.substring(5);
    } else {
      return Character.toLowerCase(className.charAt(0)) + className.substring(1);
    }
  }

  protected void writeAttributes(XMLWriter writer, T object) throws IOException {
  }
  
  protected void writeChildren(XMLWriter writer, T object) throws IOException {
  }
}